@@ -214,11 +214,11 @@ setMethod("as.polygons", signature(x="SpatRaster"),
 	
 		p <- methods::new("SpatVector")
 		if (extent) {
-			p@pnt <- x@pnt$dense_extent(FALSE, FALSE)
+			p@cpp <- x@cpp$dense_extent(FALSE, FALSE)
 			x <- messages(x, "as.polygons")
 		} else {
 			opt <- spatOptions()
-			p@pnt <- x@pnt$as_polygons(round[1], aggregate[1], values[1], na.rm[1], na.all[1], digits, opt)
+			p@cpp <- x@cpp$as_polygons(round[1], aggregate[1], values[1], na.rm[1], na.all[1], digits, opt)
 			x <- messages(x, "as.polygons")
 			if (values) {
 				p <- get_labels(x, p, aggregate[1])
@@ -232,7 +232,7 @@ setMethod("as.lines", signature(x="SpatRaster"),
 	function(x) {
 		p <- methods::new("SpatVector")
 		opt <- spatOptions()
-		p@pnt <- x@pnt$as_lines(opt)
+		p@cpp <- x@cpp$as_lines(opt)
 		messages(p, "as.lines")
 	}
 )
@@ -242,7 +242,7 @@ setMethod("as.polygons", signature(x="SpatExtent"),
 	function(x, crs="") {
 		p <- methods::new("SpatVector")
 		crs <- character_crs(crs, "as.polygons")
-		p@pnt <- SpatVector$new(x@pnt, crs)
+		p@cpp <- SpatVector$new(x@cpp, crs)
 		messages(p, "as.polygons")
 	}
 )
@@ -257,7 +257,7 @@ setMethod("as.lines", signature(x="SpatExtent"),
 
 setMethod("as.points", signature(x="SpatExtent"),
 	function(x, crs="") {
-		#vect(do.call(cbind, x@pnt$as.points()), "points", crs=crs)
+		#vect(do.call(cbind, x@cpp$as.points()), "points", crs=crs)
 		as.points(as.polygons(x, crs))
 	}
 )
@@ -265,7 +265,7 @@ setMethod("as.points", signature(x="SpatExtent"),
 
 setMethod("as.lines", signature(x="SpatVector"),
 	function(x) {
-		x@pnt <- x@pnt$as_lines()
+		x@cpp <- x@cpp$as_lines()
 		messages(x, "as.lines")
 	}
 )
@@ -275,7 +275,7 @@ setMethod("as.polygons", signature(x="SpatVector"),
 		if (extent) {
 			as.polygons(ext(x), crs=crs(x))
 		} else {
-			x@pnt <- x@pnt$polygonize()
+			x@cpp <- x@cpp$polygonize()
 			messages(x, "as.polygons")
 		}
 	}
@@ -284,7 +284,7 @@ setMethod("as.polygons", signature(x="SpatVector"),
 setMethod("as.points", signature(x="SpatVector"),
 	function(x, multi=FALSE, skiplast=TRUE) {
 		opt <- spatOptions()
-		x@pnt <- x@pnt$as_points(multi, skiplast)
+		x@cpp <- x@cpp$as_points(multi, skiplast)
 		messages(x, "as.points")
 	}
 )
@@ -294,7 +294,7 @@ setMethod("as.points", signature(x="SpatRaster"),
 	function(x, values=TRUE, na.rm=TRUE, na.all=FALSE) {
 		p <- methods::new("SpatVector")
 		opt <- spatOptions()
-		p@pnt <- x@pnt$as_points(values, na.rm, na.all, opt)
+		p@cpp <- x@cpp$as_points(values, na.rm, na.all, opt)
 		x <- messages(x, "as.points")
 
 		if (values) {
@@ -307,7 +307,7 @@ setMethod("as.points", signature(x="SpatRaster"),
 # mode argument is ignored as mode=mode gave an error on R-devel
 setMethod("as.vector", signature(x="SpatExtent"),
 	function(x, mode="any") {
-		v <- x@pnt$vector
+		v <- x@cpp$vector
 		names(v) <- c("xmin", "xmax", "ymin", "ymax")
 		if (mode == "list") {
 			v <- as.list(v)
@@ -421,7 +421,7 @@ setMethod("as.array", signature(x="SpatRaster"),
 # to sf from SpatVector
 # available in sf
 #.v2sf <- function(from) {
-#	txt <- 'sf::st_as_sf(as.data.frame(from, geom=TRUE), wkt="geometry", crs=from@pnt$get_crs("wkt"))'
+#	txt <- 'sf::st_as_sf(as.data.frame(from, geom=TRUE), wkt="geometry", crs=from@cpp$get_crs("wkt"))'
 #	eval(parse(text = txt))
 #}
 
@@ -440,7 +440,7 @@ setMethod("as.array", signature(x="SpatRaster"),
 	#geom <- st_as_text(geom)
 	#v <- vect(geom, crs=crs)
 	v <- vect()
-	v@pnt <- v@pnt$from_hex(sf::rawToHex(sf::st_as_binary(geom)), crs)
+	v@cpp <- v@cpp$from_hex(sf::rawToHex(sf::st_as_binary(geom)), crs)
 	v <- messages(v, "SpatVector from sf")
 	if (ncol(from) > 1) {
 		from[[sfi]] <- NULL
@@ -457,7 +457,7 @@ setMethod("as.array", signature(x="SpatRaster"),
 	#geom <- st_as_text(geom)
 	#v <- vect(geom, crs=crs)
 	v <- svc()
-	v@pnt <- v@pnt$from_hex_col(sf::rawToHex(sf::st_as_binary(geom)), crs)
+	v@cpp <- v@cpp$from_hex_col(sf::rawToHex(sf::st_as_binary(geom)), crs)
 	#if (ncol(from) > 1) {
 	#	from[[sfi]] <- NULL
 	#	values(v) <- as.data.frame(from)
@@ -483,7 +483,7 @@ setAs("sf", "SpatVector",
 		if (inherits(geom, "list")) {
 			error("as,sf", "the geometry column is not valid (perhaps first load the sf package)")
 		}
-		v <- try(.from_sf(from, geom, sfi), silent=TRUE)
+		v <- try(.from_sf(from, geom, sfi), silent=FALSE)
 		if (inherits(v, "try-error")) {
 			error("as,sf", "coercion failed. You can try coercing via a Spatial* (sp) class")
 		}
@@ -493,7 +493,7 @@ setAs("sf", "SpatVector",
 
 .from_sfc <- function(from) {
 	v <- vect()
-	v@pnt <- v@pnt$from_hex(sf::rawToHex(sf::st_as_binary(from)), "")
+	v@cpp <- v@cpp$from_hex(sf::rawToHex(sf::st_as_binary(from)), "")
 	crs(v, warn=FALSE) <- attr(from, "crs")$wkt
 	v
 }
