@@ -3,9 +3,52 @@
 # Version 1.0
 # License GPL v3
 
+setMethod("metags", signature(x="SpatRaster"),
+	function(x, name=NULL) {
+		v <- x@cpp$getTags()
+		m <- matrix(v, ncol=2, byrow=TRUE, dimnames = list(NULL, c("name", "value")))
+		out <- m[,2]
+		names(out) <- m[,1]
+		if (!is.null(name)) {
+			out <- out[name]
+		} 
+		out
+	}
+)
+
+
+setMethod("metags<-", signature(x="SpatRaster"),
+	function(x, value) {
+		if (is.null(value)) {
+			value <- matrix(x@cpp$getTags(), ncol=2, byrow=TRUE)
+			value[,2] <- ""
+		} else if (NCOL(value) == 1) {
+			value <- strsplit(value, "=")
+			i <- sapply(value, length) == 1
+			if (length(i) > 0) {
+				j <- which(i)
+				for (i in j) value[[i]] <- c(value[[i]], "")
+			}
+			i <- sapply(value, length) == 2
+			value <- do.call(rbind, value[i])
+		} else if (NCOL(value) != 2) {
+			error("metags<-", "expecting a vector with 'name=value' or a two column matrix")
+		}
+		value[is.na(value)] <- ""
+		x <- deepcopy(x)
+		if (NROW(value) > 0) {
+			sapply(1:nrow(value), function(i) {
+				x@cpp$addTag(value[i,1], value[i,2])
+			})
+		}
+		x
+	}
+)
+
+
 setMethod("is.rotated", signature(x="SpatRaster"),
 	function(x) {
-		x@pnt$is_rotated()
+		x@cpp$is_rotated()
 	}
 )
 
@@ -13,7 +56,7 @@ setMethod("is.rotated", signature(x="SpatRaster"),
 setMethod("rangeFill", signature(x="SpatRaster"),
 	function(x, limit, circular=FALSE, filename="", ...) {
 		opt <- spatOptions(filename, ...)
-		x@pnt <- x@pnt$fill_range(limit, circular, opt)
+		x@cpp <- x@cpp$fill_range(limit, circular, opt)
 		messages(x, "rangeFill")
 	}
 )
@@ -27,7 +70,7 @@ setMethod("meta", signature(x="SpatRaster"),
 				matrix(unlist(regmatches(i, regexpr("=", i), invert=TRUE)), ncol=2, byrow=TRUE)
 			}
 		}
-		lapply(x@pnt$metadata(layers), f)
+		lapply(x@cpp$metadata(layers), f)
 	}
 )
 
@@ -35,7 +78,7 @@ setMethod("meta", signature(x="SpatRaster"),
 setMethod("weighted.mean", signature(x="SpatRaster", w="numeric"),
 	function(x, w, na.rm=FALSE, filename="", ...) {
 		opt <- spatOptions(filename, ...)
-		x@pnt <- x@pnt$wmean_vect(w, na.rm, opt)
+		x@cpp <- x@cpp$wmean_vect(w, na.rm, opt)
 		messages(x, "weighted.mean")
 	}
 )
@@ -44,7 +87,7 @@ setMethod("weighted.mean", signature(x="SpatRaster", w="numeric"),
 setMethod("weighted.mean", signature(x="SpatRaster", w="SpatRaster"),
 	function(x, w, na.rm=FALSE, filename="", ...) {
 		opt <- spatOptions(filename, ...)
-		x@pnt <-x@pnt$wmean_rast(w@pnt, na.rm, opt)
+		x@cpp <-x@cpp$wmean_rast(w@cpp, na.rm, opt)
 		messages(x, "weighted.mean")
 	}
 )
@@ -55,11 +98,11 @@ setMethod("patches", signature(x="SpatRaster"),
 	function(x, directions=4, zeroAsNA=FALSE, allowGaps=TRUE, filename="", ...) {
 		if (allowGaps) {
 			opt <- spatOptions(filename, ...)
-			x@pnt <- x@pnt$patches(directions[1], zeroAsNA[1], opt)
+			x@cpp <- x@cpp$patches(directions[1], zeroAsNA[1], opt)
 			messages(x, "patches")
 		} else {
 			opt <- spatOptions()
-			x@pnt <- x@pnt$patches(directions[1], zeroAsNA[1], opt)
+			x@cpp <- x@cpp$patches(directions[1], zeroAsNA[1], opt)
 			x <- messages(x, "patches")
 			f <- freq(x)
 			fr <- cbind(f[,2], 1:nrow(f))
@@ -77,7 +120,7 @@ setMethod("patches", signature(x="SpatRaster"),
 
 setMethod("origin", signature(x="SpatRaster"),
 	function(x) {
-		x@pnt$origin
+		x@cpp$origin
 	}
 )
 
@@ -115,7 +158,7 @@ setMethod("origin<-", signature("SpatRaster"),
 
 setMethod("align", signature(x="SpatExtent", y="SpatRaster"),
 	function(x, y, snap="near") {
-		x@pnt <- y@pnt$align(x@pnt, tolower(snap))
+		x@cpp <- y@cpp$align(x@cpp, tolower(snap))
 		#messages(x, "align")
 		x
 	}
@@ -123,7 +166,7 @@ setMethod("align", signature(x="SpatExtent", y="SpatRaster"),
 
 setMethod("align", signature(x="SpatExtent", y="numeric"),
 	function(x, y) {
-		x@pnt <- x@pnt$align(y, "")
+		x@cpp <- x@cpp$align(y, "")
 		x
 	}
 )
@@ -132,7 +175,7 @@ setMethod("align", signature(x="SpatExtent", y="numeric"),
 setMethod("intersect", signature(x="SpatRaster", y="SpatRaster"),
 	function(x, y) {
 		opt <- spatOptions() 
-		x@pnt <- x@pnt$intersect(y@pnt, opt)
+		x@cpp <- x@cpp$intersect(y@cpp, opt)
 		messages(x)
 	}
 )
@@ -142,7 +185,7 @@ setMethod("cellSize", signature(x="SpatRaster"),
 	function(x, mask=FALSE, lyrs=FALSE, unit="m", transform=TRUE, rcx=100, filename="", ...) {
 		opt <- spatOptions(filename, ...)
 		if (!lyrs) x <- x[[1]]
-		x@pnt <- x@pnt$rst_area(mask, unit, transform, rcx, opt)
+		x@cpp <- x@cpp$rst_area(mask, unit, transform, rcx, opt)
 		messages(x, "cellSize")
 	}
 )
@@ -151,7 +194,7 @@ setMethod("cellSize", signature(x="SpatRaster"),
 setMethod("atan2", signature(y="SpatRaster", x="SpatRaster"),
 	function(y, x) {
 		opt <- spatOptions(filename="", overwrite=TRUE)
-		y@pnt <- y@pnt$atan2(x@pnt, opt)
+		y@cpp <- y@cpp$atan2(x@cpp, opt)
 		messages(y, "atan2")
 	}
 )
@@ -159,7 +202,7 @@ setMethod("atan2", signature(y="SpatRaster", x="SpatRaster"),
 setMethod("atan_2", signature(y="SpatRaster", x="SpatRaster"),
 	function(y, x, filename="", ...) {
 		opt <- spatOptions(filename=filename, ...)
-		y@pnt <- y@pnt$atan2(x@pnt, opt)
+		y@cpp <- y@cpp$atan2(x@cpp, opt)
 		messages(y, "atan_2")
 	}
 )
@@ -169,20 +212,20 @@ setMethod("boundaries", signature(x="SpatRaster"),
 	function(x, classes=FALSE, inner=TRUE, directions=8, falseval=0, filename="", ...) {
 		opt <- spatOptions(filename, ...)
 		type <- ifelse(inner[1], "inner", "outer")
-		x@pnt <- x@pnt$boundaries(classes[1], type, directions[1], falseval[1], opt)
+		x@cpp <- x@cpp$boundaries(classes[1], type, directions[1], falseval[1], opt)
 		messages(x, "boundaries")
 	}
 )
 
 
 .collapseSources <- function(x) {
-	x@pnt <- x@pnt$collapse_sources()
+	x@cpp <- x@cpp$collapse_sources()
 	messages(x, "tighten")
 }
 
 setMethod("deepcopy", signature("SpatRaster"),
 	function(x) {
-		x@pnt <- x@pnt$deepcopy()
+		x@cpp <- x@cpp$deepcopy()
 		x
 	}
 )
@@ -201,18 +244,18 @@ setMethod("split", signature(x="SpatRaster"),
 
 setMethod("add<-", signature("SpatRaster", "SpatRaster"),
 	function(x, value) {
-		if (x@pnt$same(value@pnt)) {
-			x@pnt <- x@pnt$deepcopy()
+		if (x@cpp$same(value@cpp)) {
+			x@cpp <- x@cpp$deepcopy()
 		}
 		opt <- spatOptions()
-		x@pnt$addSource(value@pnt, FALSE, opt)
+		x@cpp$addSource(value@cpp, FALSE, opt)
 		messages(x, "add")
 	}
 )
 
 setMethod("tighten", signature("SpatRaster"),
 	function(x) {
-		x@pnt <- x@pnt$collapse_sources()
+		x@cpp <- x@cpp$collapse_sources()
 		messages(x, "tighten")
 	}
 )
@@ -220,7 +263,7 @@ setMethod("tighten", signature("SpatRaster"),
 setMethod("tighten", signature("SpatRasterDataset"),
 	function(x) {
 		y <- new("SpatRaster")
-		y@pnt <- x@pnt$collapse()
+		y@cpp <- x@cpp$collapse()
 		messages(y, "tighten")
 	}
 )
@@ -229,9 +272,9 @@ setMethod("tighten", signature("SpatRasterDataset"),
 #setMethod("c", signature(x="SpatRaster"),
 #	function(x, ...) {
 #		s <- sds(list(x, ...))
-#		x@pnt <- s@pnt$collapse()
+#		x@cpp <- s@cpp$collapse()
 #		x <- messages(x, "c")
-#		try( x@pnt <- x@pnt$collapse_sources() )
+#		try( x@cpp <- x@cpp$collapse_sources() )
 #		messages(x, "c")
 #	}
 #)
@@ -240,12 +283,12 @@ setMethod("tighten", signature("SpatRasterDataset"),
 
 #cbind.SpatVector <- function(x, y, ...) {
 #	if (inherits(y, "SpatVector")) {
-#		y <- y@pnt$df
+#		y <- y@cpp$df
 #	} else {
 #		stopifnot(inherits(y, "data.frame"))
 #		y <- terra:::.makeSpatDF(y)
 #	}
-#	x@pnt <- x@pnt$cbind(y)
+#	x@cpp <- x@cpp$cbind(y)
 #	messages(x, "cbind")
 #}
 
@@ -253,12 +296,12 @@ cbind.SpatVector <- function(x, y, ...) {
 	dots <- list(y, ...)
 	for (y in dots) {
 		if (inherits(y, "SpatVector")) {
-			y <- y@pnt$df
+			y <- y@cpp$df
 		} else {
 			stopifnot(inherits(y, "data.frame"))
 			y <- .makeSpatDF(y)
 		}
-		x@pnt <- x@pnt$cbind(y)
+		x@cpp <- x@cpp$cbind(y)
 		x <- messages(x, "cbind")
 	}
 	x
@@ -269,18 +312,18 @@ rbind.SpatVector <- function(x, y, ...) {
 	if (missing(y) || is.null(y)) return(x)
 	stopifnot(inherits(y, "SpatVector"))
 	s <- svc(x, y, ...)
-	x@pnt <- s@pnt$append()
+	x@cpp <- s@cpp$append()
 	messages(x, "rbind")
 
 #	dots <- list(...)
 #	if (is.null(dots)) {
-#		x@pnt <- x@pnt$rbind(y@pnt, FALSE)
+#		x@cpp <- x@cpp$rbind(y@cpp, FALSE)
 #	} else {
 
 	#if (!is.null(dots)) {
 	#	for (y in dots) {
 	#		stopifnot(inherits(y, "SpatVector"))
-	#		x@pnt <- x@pnt$rbind(y@pnt, FALSE)
+	#		x@cpp <- x@cpp$rbind(y@cpp, FALSE)
 	#		x <- messages(x, "rbind")
 	#	}
 	#}
@@ -315,18 +358,18 @@ setMethod("clamp", signature(x="SpatRaster"),
 		rupp <- inherits(upper, "SpatRaster")
 		r <- rast()
 		if (rlow & rupp) {
-			x@pnt <- x@pnt$clamp_raster(lower@pnt, upper@pnt, NA, NA, values[1], opt)
+			x@cpp <- x@cpp$clamp_raster(lower@cpp, upper@cpp, NA, NA, values[1], opt)
 		} else if (rlow) {
 			if (any(is.na(upper))) error("clamp", "upper limit cannot be NA")
-			x@pnt <- x@pnt$clamp_raster(lower@pnt, r@pnt, NA, upper, values[1], opt)
+			x@cpp <- x@cpp$clamp_raster(lower@cpp, r@cpp, NA, upper, values[1], opt)
 		} else if (rupp) {
 			if (any(is.na(lower))) error("clamp", "lower limit cannot be NA")
-			x@pnt <- x@pnt$clamp_raster(r@pnt, upper@pnt, lower, NA, values[1], opt)
+			x@cpp <- x@cpp$clamp_raster(r@cpp, upper@cpp, lower, NA, values[1], opt)
 		} else {
 			if (any(is.na(lower))) error("clamp", "lower limit cannot be NA")
 			if (any(is.na(upper))) error("clamp", "upper limit cannot be NA")
-			x@pnt <- x@pnt$clamp_raster(r@pnt, r@pnt, lower, upper, values[1], opt)
-			#x@pnt <- x@pnt$clamp(lower, upper, values[1], opt)
+			x@cpp <- x@cpp$clamp_raster(r@cpp, r@cpp, lower, upper, values[1], opt)
+			#x@cpp <- x@cpp$clamp(lower, upper, values[1], opt)
 		}
 		messages(x, "clamp")
 	}
@@ -337,7 +380,7 @@ setMethod("clamp", signature(x="SpatRaster"),
 setMethod("clamp_ts", signature(x="SpatRaster"),
 	function(x, min=FALSE, max=TRUE, filename="", ...) {
 		opt <- spatOptions(filename, ...)
-		x@pnt <- x@pnt$clamp_ts(min, max, opt)
+		x@cpp <- x@cpp$clamp_ts(min, max, opt)
 		messages(x, "clamp_ts")
 	}
 )
@@ -377,7 +420,7 @@ function(x, rcl, include.lowest=FALSE, right=TRUE, others=NULL, brackets=TRUE, f
 		others <- TRUE
 	}
 	keepcats <- FALSE
-    x@pnt <- x@pnt$classify(as.vector(rcl), NCOL(rcl), right, include.lowest, others, othersValue, bylayer[1], brackets[1], keepcats, opt)
+    x@cpp <- x@cpp$classify(as.vector(rcl), NCOL(rcl), right, include.lowest, others, othersValue, bylayer[1], brackets[1], keepcats, opt)
 	messages(x, "classify")
 }
 )
@@ -460,11 +503,11 @@ function(x, from, to, others=NULL, raw=FALSE, filename="", ...) {
 	if (tom) {
 		nms <- colnames(to)
 		if (!is.null(nms)) 	opt$names = nms
-		x@pnt <- x@pnt$replaceValues(from, to, ncol(to), setothers, others, keepcats, opt)
+		x@cpp <- x@cpp$replaceValues(from, to, ncol(to), setothers, others, keepcats, opt)
 	} else if (frm) {
-		x@pnt <- x@pnt$replaceValues(as.vector(t(from)), to, -ncol(from), setothers, others, FALSE, opt)
+		x@cpp <- x@cpp$replaceValues(as.vector(t(from)), to, -ncol(from), setothers, others, FALSE, opt)
 	} else {
-		x@pnt <- x@pnt$replaceValues(from, to, 0, setothers, others, keepcats, opt)
+		x@cpp <- x@cpp$replaceValues(from, to, 0, setothers, others, keepcats, opt)
 	}
 	messages(x, "subst")
 }
@@ -491,14 +534,14 @@ setMethod("crop", signature(x="SpatRaster", y="ANY"),
 		opt <- spatOptions(filename, ...)
 		if (mask) {
 			if (inherits(y, "SpatVector")) {
-				x@pnt <- x@pnt$crop_mask(y@pnt, snap[1], touches[1], extend[1], opt)
+				x@cpp <- x@cpp$crop_mask(y@cpp, snap[1], touches[1], extend[1], opt)
 			} else if (inherits(y, "sf")) {
 				y <- vect(y)
-				x@pnt <- x@pnt$crop_mask(y@pnt, snap[1], touches[1], extend[1], opt)
+				x@cpp <- x@cpp$crop_mask(y@cpp, snap[1], touches[1], extend[1], opt)
 			} else if (inherits(y, "SpatRaster")) {
 				mopt <- spatOptions(filename="", ...)
 				e <- ext(y)
-				x@pnt <- x@pnt$crop(e@pnt, snap[1], extend[1], mopt)
+				x@cpp <- x@cpp$crop(e@cpp, snap[1], extend[1], mopt)
 				x <- messages(x, "crop")
 				if (compareGeom(x, y, lyrs=FALSE, crs=FALSE, warncrs=FALSE, ext=TRUE, rowcol=TRUE, res=FALSE, stopOnError=FALSE, messages=FALSE)) {
 					return(mask(x, y, filename=filename, ...))
@@ -513,11 +556,11 @@ setMethod("crop", signature(x="SpatRaster", y="ANY"),
 			} else {
 				y <- .getExt(y, method="crop")
 				warn("crop", paste("mask=TRUE is ignored for", class(y)[1], "objects"))
-				x@pnt <- x@pnt$crop(y@pnt, snap[1], extend[1], opt)
+				x@cpp <- x@cpp$crop(y@cpp, snap[1], extend[1], opt)
 			}
 		} else {
 			y <- .getExt(y, method="crop")
-			x@pnt <- x@pnt$crop(y@pnt, snap[1], extend[1], opt)
+			x@cpp <- x@cpp$crop(y@cpp, snap[1], extend[1], opt)
 		}
 		messages(x, "crop")
 	}
@@ -528,7 +571,7 @@ setMethod("crop", signature(x="SpatRasterDataset", y="ANY"),
 	function(x, y, snap="near", extend=FALSE) {
 		opt <- spatOptions()
 		y <- .getExt(y, method="crop")
-		x@pnt <- x@pnt$crop(y@pnt, snap[1], extend[1], opt)
+		x@cpp <- x@cpp$crop(y@cpp, snap[1], extend[1], opt)
 		messages(x, "crop")
 	}
 )
@@ -537,7 +580,7 @@ setMethod("crop", signature(x="SpatRasterCollection", y="ANY"),
 	function(x, y, snap="near", extend=FALSE) {
 		y <- .getExt(y, method="crop")
 		opt <- spatOptions()
-		x@pnt <- x@pnt$crop(y@pnt, snap[1], extend[1], double(), opt)
+		x@cpp <- x@cpp$crop(y@cpp, snap[1], extend[1], double(), opt)
 		messages(x, "crop")
 	}
 )
@@ -546,7 +589,7 @@ setMethod("crop", signature(x="SpatRasterCollection", y="ANY"),
 setMethod("selectRange", signature(x="SpatRaster"),
 	function(x, y, z=1, repint=0, filename="", ...) {
 		opt <- spatOptions(filename, ...)
-		x@pnt <- x@pnt$selRange(y@pnt, z, repint, opt)
+		x@cpp <- x@cpp$selRange(y@cpp, z, repint, opt)
 		messages(x, "selectRange")
 	}
 )
@@ -554,7 +597,7 @@ setMethod("selectRange", signature(x="SpatRaster"),
 setMethod("cover", signature(x="SpatRaster", y="SpatRaster"),
 	function(x, y, values=NA, filename="", ...) {
 		opt <- spatOptions(filename, ...)
-		x@pnt <- x@pnt$cover(y@pnt, values, opt)
+		x@cpp <- x@cpp$cover(y@cpp, values, opt)
 		messages(x, "cover")
 	}
 )
@@ -570,7 +613,7 @@ setMethod("diff", signature(x="SpatRaster"),
 		y <- x[[-((n-lag+1):n)]]
 		x <- x[[-(1:lag)]]
 		opt <- spatOptions(filename, ...)
-		x@pnt <- x@pnt$arith_rast(y@pnt, "-", FALSE, opt)
+		x@cpp <- x@cpp$arith_rast(y@cpp, "-", FALSE, opt)
 		messages(x, "diff")
 	}
 )
@@ -585,7 +628,7 @@ setMethod("disagg", signature(x="SpatRaster"),
 			return(r)
 		}
 		opt <- spatOptions(filename, ...)
-		x@pnt <- x@pnt$disaggregate(fact, opt)
+		x@cpp <- x@cpp$disaggregate(fact, opt)
 		messages(x, "disagg")
 	}
 )
@@ -595,7 +638,7 @@ setMethod("flip", signature(x="SpatRaster"),
 	function(x, direction="vertical", filename="", ...) {
 		d <- match.arg(direction, c("vertical", "horizontal"))
 		opt <- spatOptions(filename, ...)
-		x@pnt <- x@pnt$flip(d == "vertical", opt)
+		x@cpp <- x@cpp$flip(d == "vertical", opt)
 		messages(x, "flip")
 	}
 )
@@ -605,7 +648,7 @@ setMethod("flip", signature(x="SpatRaster"),
 setMethod("mask", signature(x="SpatRaster", mask="SpatRaster"),
 	function(x, mask, inverse=FALSE, maskvalues=NA, updatevalue=NA, filename="", ...) {
 		opt <- spatOptions(filename, ...)
-		x@pnt <- x@pnt$mask_raster(mask@pnt, inverse[1], maskvalues, updatevalue[1], opt)
+		x@cpp <- x@cpp$mask_raster(mask@cpp, inverse[1], maskvalues, updatevalue[1], opt)
 		messages(x, "mask")
 	}
 )
@@ -613,7 +656,7 @@ setMethod("mask", signature(x="SpatRaster", mask="SpatRaster"),
 setMethod("mask", signature(x="SpatRaster", mask="SpatVector"),
 	function(x, mask, inverse=FALSE, updatevalue=NA, touches=TRUE, filename="", ...) {
 		opt <- spatOptions(filename, ...)
-		x@pnt <- x@pnt$mask_vector(mask@pnt, inverse[1], updatevalue[1], touches[1], opt)
+		x@cpp <- x@cpp$mask_vector(mask@cpp, inverse[1], updatevalue[1], touches[1], opt)
 		messages(x, "mask")
 	}
 )
@@ -626,10 +669,10 @@ setMethod("mask", signature(x="SpatRaster", mask="sf"),
 )
 
 setMethod("project", signature(x="SpatRaster"),
-	function(x, y, method, mask=FALSE, align=FALSE, gdal=TRUE, res=NULL, origin=NULL, threads=FALSE, filename="", ..., by_util = FALSE)  {
+	function(x, y, method, mask=FALSE, align=FALSE, res=NULL, origin=NULL, threads=FALSE, filename="", ..., use_gdal=TRUE, by_util = FALSE)  {
 
 		if (missing(method)) {
-			if (is.factor(x)[1] || isTRUE(x@pnt$rgb)) {
+			if (is.factor(x)[1] || isTRUE(x@cpp$rgb)) {
 				method <- "near"
 			} else {
 				method <- "bilinear"
@@ -644,18 +687,18 @@ setMethod("project", signature(x="SpatRaster"),
 		opt <- spatOptions(filename, threads=threads, ...)
 
 		if (inherits(y, "SpatRaster")) {
-			if (gdal) {
+			if (use_gdal) {
 
 				if (by_util) {
-						x@pnt <- x@pnt$warp_by_util(y@pnt, "", method, mask[1], align[1], FALSE, opt)
+						x@cpp <- x@cpp$warp_by_util(y@cpp, "", method, mask[1], align[1], FALSE, opt)
 				} else {
-					x@pnt <- x@pnt$warp(y@pnt, "", method, mask[1], align[1], FALSE, opt)
+					x@cpp <- x@cpp$warp(y@cpp, "", method, mask[1], align[1], FALSE, opt)
 				}
 			} else {
 				if (align) {
 					y <- project(rast(x), y, align=TRUE)
 				}
-				x@pnt <- x@pnt$resample(y@pnt, method, mask[1], TRUE, opt)
+				x@cpp <- x@cpp$resample(y@cpp, method, mask[1], TRUE, opt)
 			}
 		} else {
 			if (!is.character(y)) {
@@ -666,19 +709,19 @@ setMethod("project", signature(x="SpatRaster"),
 				tmp <- project(rast(x), y)
 				if (!is.null(res)) res(tmp) <- res
 				if (!is.null(origin)) origin(tmp) <- origin
-				return(project(x, tmp, method=method, mask=mask, align=align, gdal=gdal, filename=filename, ...))
+				return(project(x, tmp, method=method, mask=mask, align=align, filename=filename, use_gdal=use_gdal, by_util=by_util, ...))
 			}
-			if (gdal) {
+			if (use_gdal) {
 
 				if (by_util) {
-					x@pnt <- x@pnt$warp_by_util(SpatRaster$new(), y, method, mask, FALSE, FALSE, opt)
+					x@cpp <- x@cpp$warp_by_util(SpatRaster$new(), y, method, mask, FALSE, FALSE, opt)
 					
 				} else {
-					x@pnt <- x@pnt$warp(SpatRaster$new(), y, method, mask, FALSE, FALSE, opt)
+					x@cpp <- x@cpp$warp(SpatRaster$new(), y, method, mask, FALSE, FALSE, opt)
 				}
 			} else {
 				y <- project(rast(x), y)
-				x@pnt <- x@pnt$resample(y@pnt, method, mask[1], TRUE, opt)
+				x@cpp <- x@cpp$resample(y@cpp, method, mask[1], TRUE, opt)
 			}
 		}
 		messages(x, "project")
@@ -691,7 +734,7 @@ setMethod("project", signature(x="SpatVector"),
 		if (!is.character(y)) {
 			y <- as.character(crs(y))
 		}
-		x@pnt <- x@pnt$project(y, partial)
+		x@cpp <- x@cpp$project(y, partial)
 		messages(x, "project")
 	}
 )
@@ -724,9 +767,9 @@ setMethod("project", signature(x="matrix"),
            to <- as.character(crs(to))
         }
 		#v <- vect(x, type="line", crs=from)
-        #v@pnt <- v@pnt$project(to)
+        #v@cpp <- v@cpp$project(to)
         v <- vect()
-		xy <- v@pnt$project_xy(x[,1], x[,2], from, to)
+		xy <- v@cpp$project_xy(x[,1], x[,2], from, to)
 		messages(v, "project")
 		matrix(xy, ncol=2)
     }
@@ -736,7 +779,7 @@ setMethod("project", signature(x="matrix"),
 setMethod("quantile", signature(x="SpatRaster"),
 	function(x, probs=seq(0, 1, 0.25), na.rm=FALSE, filename="", ...) {
 		opt <- spatOptions(filename, ...)
-		x@pnt <- x@pnt$quantile(probs, na.rm[1], opt)
+		x@cpp <- x@cpp$quantile(probs, na.rm[1], opt)
 		messages(x, "quantile")
 	}
 )
@@ -772,7 +815,7 @@ setMethod("rectify", signature(x="SpatRaster"),
 			useaoi <- 0
 		}
 		snap <- as.logical(snap)
-		x@pnt <- x@pnt$rectify(method, aoi@pnt, useaoi, snap, opt)
+		x@cpp <- x@cpp$rectify(method, aoi@cpp, useaoi, snap, opt)
 		messages(x, "rectify")
 	}
 )
@@ -797,9 +840,9 @@ setMethod("resample", signature(x="SpatRaster", y="SpatRaster"),
 		}
 		opt <- spatOptions(filename, threads=threads, ...)
 #		if (gdal) {
-			x@pnt <- x@pnt$warp(y@pnt, "", method, FALSE, FALSE, TRUE, opt)
+			x@cpp <- x@cpp$warp(y@cpp, "", method, FALSE, FALSE, TRUE, opt)
 #		} else {
-#			x@pnt <- x@pnt$resample(y@pnt, method, FALSE, TRUE, opt)
+#			x@cpp <- x@cpp$resample(y@cpp, method, FALSE, TRUE, opt)
 #		}
 		messages(x, "resample")
 	}
@@ -812,7 +855,7 @@ setMethod("impose", signature(x="SpatRasterCollection"),
 		stopifnot(inherits(y, "SpatRaster"))
 		opt <- spatOptions(filename, ...)
 		r <- rast()
-		r@pnt <- x@pnt$morph(y@pnt, opt)
+		r@cpp <- x@cpp$morph(y@cpp, opt)
 		messages(r, "impose")
 	}
 )
@@ -822,7 +865,7 @@ setMethod("impose", signature(x="SpatRasterCollection"),
 setMethod("rev", signature(x="SpatRaster"),
 	function(x) {
 		opt <- spatOptions("", FALSE, list())
-		x@pnt <- x@pnt$reverse(opt)
+		x@cpp <- x@cpp$reverse(opt)
 		messages(x, "rev")
 	}
 )
@@ -830,7 +873,7 @@ setMethod("rev", signature(x="SpatRaster"),
 setMethod("rotate", signature(x="SpatRaster"),
 	function(x, left=TRUE, filename="", ...) {
 		opt <- spatOptions(filename, ...)
-		x@pnt <- x@pnt$rotate(left, opt)
+		x@cpp <- x@cpp$rotate(left, opt)
 		messages(x, "rotate")
 	}
 )
@@ -866,7 +909,7 @@ setMethod("rotate", signature(x="SpatVector"),
 			} 
 			x$unique_id_for_aggregation <- NULL
 		} else {
-			x@pnt <- x@pnt$rotate_longitude(longitude, left)
+			x@cpp <- x@cpp$rotate_longitude(longitude, left)
 			x <- messages(x, "rotate")
 		}
 		if (normalize) {
@@ -880,7 +923,7 @@ setMethod("segregate", signature(x="SpatRaster"),
 	function(x, classes=NULL, keep=FALSE, other=0, round=FALSE, digits=0, filename="", ...) {
 		opt <- spatOptions(filename, ...)
 		if (is.null(classes)) classes <- 1[0]
-		x@pnt <- x@pnt$separate(classes, keep[1], other[1], round[1], digits[1], opt)
+		x@cpp <- x@cpp$separate(classes, keep[1], other[1], round[1], digits[1], opt)
 		messages(x, "segregate")
 	}
 )
@@ -889,7 +932,7 @@ setMethod("segregate", signature(x="SpatRaster"),
 setMethod("shift", signature(x="SpatRaster"),
 	function(x, dx=0, dy=0, filename="", ...) {
 		opt <- spatOptions(filename, ...)
-		x@pnt <- x@pnt$shift(dx, dy, opt)
+		x@cpp <- x@cpp$shift(dx, dy, opt)
 		messages(x, "shift")
 	}
 )
@@ -905,7 +948,7 @@ setMethod("shift", signature(x="SpatExtent"),
 
 setMethod("shift", signature(x="SpatVector"),
 	function(x, dx=0, dy=0) {
-		x@pnt <- x@pnt$shift(dx, dy)
+		x@cpp <- x@cpp$shift(dx, dy)
 		messages(x, "shift")
 	}
 )
@@ -923,7 +966,7 @@ setMethod("rescale", signature(x="SpatRaster"),
 		}
 		ex = x0 + fx * (e[1:2] - x0);
 		ey = y0 + fy * (e[3:4] - y0);
-		x@pnt <- x@pnt$deepcopy()
+		x@cpp <- x@cpp$deepcopy()
 		ext(x) <- ext(c(ex, ey))
 		messages(x, "rescale")
 	}
@@ -940,7 +983,7 @@ setMethod("rescale", signature(x="SpatVector"),
 		if (missing(y0)) {
 			y0 <- mean(e[3:4])
 		}
-		x@pnt <- x@pnt$rescale(fx, fy, x0[1], y0[1])
+		x@cpp <- x@cpp$rescale(fx, fy, x0[1], y0[1])
 		messages(x, "rescale")
 	}
 )
@@ -963,7 +1006,7 @@ setMethod("scale", signature(x="SpatRaster"),
 		} else {
 			doscale = TRUE;
 		}
-		x@pnt <- x@pnt$scale(center, docenter, scale, doscale, opt)
+		x@cpp <- x@cpp$scale(center, docenter, scale, doscale, opt)
 		messages(x, "scale")
 	}
 )
@@ -971,16 +1014,29 @@ setMethod("scale", signature(x="SpatRaster"),
 
 
 setMethod("stretch", signature(x="SpatRaster"),
-	function(x, minv=0, maxv=255, minq=0, maxq=1, smin=NA, smax=NA, histeq=FALSE, scale=1, filename="", ...) {
-		opt <- spatOptions(filename, ...)
+	function(x, minv=0, maxv=255, minq=0, maxq=1, smin=NA, smax=NA, histeq=FALSE, scale=1, maxcell=500000, filename="", ...) {
 		if (histeq) {
-			eqStretch <- function(x){
-				ecdfun <- stats::ecdf(x)(x)
-				ecdfun(x)
+			if (nlyr(x) > 1) {
+				x <- lapply(1:nlyr(x), function(i) stretch(x[[i]], histeq=TRUE, scale=scale, maxcell=maxcell))
+				x <- rast(x)
+				if (filename != "") {
+					x <- writeRaster(x, filename=filename, ...)
+				}
+				return(x)
 			}
-			setValues(x, apply(values(x), 2, function(i) stats::ecdf(i)(i))) * scale
+			scale <- scale[1]
+			if (scale == 1) {
+				ecdfun <- stats::ecdf(na.omit(spatSample(x, maxcell, "regular")[,1]))
+			} else {
+				ecdfun <- function(y) {
+					f <- stats::ecdf(na.omit(spatSample(x, maxcell, "regular")[,1]))
+					f(y) * scale
+				}
+			}
+			app(x, ecdfun, filename=filename, ...)
 		} else {
-			x@pnt <- x@pnt$stretch(minv, maxv, minq, maxq, smin, smax, opt)
+			opt <- spatOptions(filename, ...)
+			x@cpp <- x@cpp$stretch(minv, maxv, minq, maxq, smin, smax, opt)
 			messages(x, "stretch")
 		}
 	}
@@ -1013,14 +1069,14 @@ setMethod("summary", signature(object="SpatVector"),
 setMethod("t", signature(x="SpatRaster"),
 	function(x) {
 		opt <- spatOptions()
-		x@pnt <- x@pnt$transpose(opt)
+		x@cpp <- x@cpp$transpose(opt)
 		messages(x, "t")
 	}
 )
 
 setMethod("t", signature(x="SpatVector"),
 	function(x) {
-		x@pnt <- x@pnt$transpose()
+		x@cpp <- x@cpp$transpose()
 		messages(x, "t")
 	}
 )
@@ -1031,7 +1087,7 @@ setMethod("terrain", signature(x="SpatRaster"),
 		unit <- match.arg(unit, c("degrees", "radians"))
 		opt <- spatOptions(filename, ...)
 		seed <- ifelse("flowdir" %in% v, .seed(), 0)
-		x@pnt <- x@pnt$terrain(v, neighbors[1], unit=="degrees", seed, opt)
+		x@cpp <- x@cpp$terrain(v, neighbors[1], unit=="degrees", seed, opt)
 		messages(x, "terrain")
 	}
 )
@@ -1047,7 +1103,7 @@ setMethod("viewshed", signature(x="SpatRaster"),
 		outops <- c("yes/no", "sea", "land")
 		output <- match.arg(tolower(output), outops)
 		output <- match(output, outops)
-		z@pnt <- x@pnt$view(c(loc[1:2], observer[1], target[1]), c(1,0,2,3), curvcoef, 2, 0, output, opt)
+		z@cpp <- x@cpp$view(c(loc[1:2], observer[1], target[1]), c(1,0,2,3), curvcoef, 2, 0, output, opt)
 		messages(z, "viewshed")
 	}
 )
@@ -1055,7 +1111,7 @@ setMethod("viewshed", signature(x="SpatRaster"),
 setMethod("sieve", signature(x="SpatRaster"),
 	function(x, threshold, directions=8, filename="", ...) {
 		opt <- spatOptions(filename, ...)
-		x@pnt <- x@pnt$sieve(threshold[1], directions[1], opt)
+		x@cpp <- x@cpp$sieve(threshold[1], directions[1], opt)
 		messages(x, "sieve")
 	}
 )
@@ -1068,7 +1124,7 @@ setMethod("trim", signature(x="SpatRaster"),
 		if (padding < 0) {
 			error("trim", "padding must be a non-negative integer")
 		}
-		x@pnt <- x@pnt$trim(value[1], padding, opt)
+		x@cpp <- x@cpp$trim(value[1], padding, opt)
 		messages(x, "trim")
 	}
 )
@@ -1076,7 +1132,7 @@ setMethod("trim", signature(x="SpatRaster"),
 setMethod("trans", signature(x="SpatRaster"),
 	function(x, filename="", ...) {
 		opt <- spatOptions(filename, ...)
-		x@pnt <- x@pnt$transpose(opt)
+		x@cpp <- x@cpp$transpose(opt)
 		messages(x, "trans")
 	}
 )
@@ -1088,7 +1144,7 @@ setMethod("unique", signature(x="SpatRaster", incomparables="ANY"),
 		opt <- spatOptions()
 
 		if (as.raster) incomparables = FALSE
-		u <- x@pnt$unique(incomparables, digits, na.rm[1], opt)
+		u <- x@cpp$unique(incomparables, digits, na.rm[1], opt)
 
 		if (!as.raster) {
 			u <- get_labels(x, u)
@@ -1146,7 +1202,7 @@ setMethod("labels", signature(object="SpatRaster"),
 
 setMethod("scoff", signature(x="SpatRaster"),
 	function(x) {
-		out <- x@pnt$getScaleOffset()
+		out <- x@cpp$getScaleOffset()
 		names(out) <- c("scale", "offset")
 		do.call(cbind, out)
 	}
@@ -1155,17 +1211,17 @@ setMethod("scoff", signature(x="SpatRaster"),
 setMethod("scoff<-", signature("SpatRaster"),
 	function(x, value) {
 		if (is.null(value)) {
-			x@pnt <- x@pnt$deepcopy()
-			x@pnt$setScaleOffset(1, 0)
+			x@cpp <- x@cpp$deepcopy()
+			x@cpp$setScaleOffset(1, 0)
 		} else {
 			if (NCOL(value) != 2) {
 				error("scoff<-", "value must be a 2-column matrix")
 			}
-			x@pnt <- x@pnt$deepcopy()
+			x@cpp <- x@cpp$deepcopy()
 			value[is.na(value[,1]),1] <- 1
 			value[is.na(value[,2]),2] <- 0
-			x@pnt$setScaleOffset(value[,1], value[,2])
-			x@pnt$setValueType(0)
+			x@cpp$setScaleOffset(value[,1], value[,2])
+			x@cpp$setValueType(0)
 		}
 		messages(x, "scoff<-")
 	}
@@ -1174,7 +1230,7 @@ setMethod("scoff<-", signature("SpatRaster"),
 setMethod("sort", signature(x="SpatRaster"),
 	function (x, decreasing=FALSE, order=FALSE, filename="", ...) {
 		opt <- spatOptions(filename, ...)
-		x@pnt <- x@pnt$sort(decreasing[1], order[1], opt)
+		x@cpp <- x@cpp$sort(decreasing[1], order[1], opt)
 		messages(x, "sort")
 	}
 )
