@@ -6,7 +6,7 @@
 
 setMethod("names", signature(x="SpatRaster"),
 	function(x) {
-		nms <- x@pnt$names
+		nms <- x@cpp$names
 		Encoding(nms) <- "UTF-8"
 		nms
 	}
@@ -23,8 +23,8 @@ setMethod("names<-", signature(x="SpatRaster"),
 				error("names<-", "incorrect number of names")
 			}
 		}
-		x@pnt <- x@pnt$deepcopy()
-		if (! x@pnt$setNames(value, FALSE)) {
+		x@cpp <- x@cpp$deepcopy()
+		if (! x@cpp$setNames(value, FALSE)) {
 			error("names<-", "cannot set these names")
 		}
 		return(x)
@@ -67,7 +67,7 @@ setMethod("names<-", signature(x="SpatRaster"),
 setMethod("set.names", signature(x="SpatRaster"),
 	function(x, value, index=1:nlyr(x), validate=FALSE)  {
 		value <- .raster_names_check(x, value, index, validate)
-		if (!x@pnt$setNames(value, FALSE)) {
+		if (!x@cpp$setNames(value, FALSE)) {
 			error("set.names", "cannot set these names")
 		}
 		invisible(TRUE)
@@ -77,7 +77,7 @@ setMethod("set.names", signature(x="SpatRaster"),
 
 setMethod("names", signature(x="SpatRasterCollection"),
 	function(x) {
-		nms <- x@pnt$names
+		nms <- x@cpp$names
 		Encoding(nms) <- "UTF-8"
 		nms
 	}
@@ -86,8 +86,8 @@ setMethod("names", signature(x="SpatRasterCollection"),
 
 setMethod("names<-", signature(x="SpatRasterCollection"),
 	function(x, value) {
-		x@pnt <- x@pnt$deepcopy()
-		x@pnt$names <- enc2utf8(as.character(value))
+		x@cpp <- x@cpp$deepcopy()
+		x@cpp$names <- enc2utf8(as.character(value))
 		x
 	}
 )
@@ -95,7 +95,7 @@ setMethod("names<-", signature(x="SpatRasterCollection"),
 setMethod("set.names", signature(x="SpatRasterCollection"),
 	function(x, value, index=1:length(x), validate=FALSE)  {
 		value <- .raster_names_check(x, value, index, validate)
-		x@pnt$names <- value
+		x@cpp$names <- value
 		invisible(TRUE)
 	}
 )
@@ -104,7 +104,7 @@ setMethod("set.names", signature(x="SpatRasterCollection"),
 
 setMethod("names", signature(x="SpatRasterDataset"),
 	function(x) {
-		nms <- x@pnt$names
+		nms <- x@cpp$names
 		Encoding(nms) <- "UTF-8"
 		nms
 	}
@@ -113,8 +113,8 @@ setMethod("names", signature(x="SpatRasterDataset"),
 
 setMethod("names<-", signature(x="SpatRasterDataset"),
 	function(x, value) {
-		x@pnt <- x@pnt$deepcopy()
-		x@pnt$names <- enc2utf8(as.character(value))
+		x@cpp <- x@cpp$deepcopy()
+		x@cpp$names <- enc2utf8(as.character(value))
 		x
 	}
 )
@@ -122,7 +122,7 @@ setMethod("names<-", signature(x="SpatRasterDataset"),
 setMethod("set.names", signature(x="SpatRasterDataset"),
 	function(x, value, index=1:length(x), validate=FALSE)  {
 		value <- .raster_names_check(x, value, index, validate)
-		x@pnt$names <- value
+		x@cpp$names <- value
 		invisible(TRUE)
 	}
 )
@@ -130,7 +130,7 @@ setMethod("set.names", signature(x="SpatRasterDataset"),
 
 setMethod("varnames", signature(x="SpatRasterDataset"),
 	function(x) {
-		nms <- x@pnt$names
+		nms <- x@cpp$names
 		Encoding(nms) <- "UTF-8"
 		nms
 	}
@@ -140,8 +140,8 @@ setMethod("varnames", signature(x="SpatRasterDataset"),
 setMethod("varnames<-", signature(x="SpatRasterDataset"),
 	function(x, value) {
 		value <- enc2utf8(as.character(value))
-		x@pnt <- x@pnt$deepcopy()
-		x@pnt$names <- value
+		x@cpp <- x@cpp$deepcopy()
+		x@cpp$names <- value
 		x
 	}
 )
@@ -150,7 +150,7 @@ setMethod("varnames<-", signature(x="SpatRasterDataset"),
 
 setMethod("names", signature(x="SpatVector"),
 	function(x) {
-		nms <- x@pnt$names
+		nms <- x@cpp$names
 		Encoding(nms) <- "UTF-8"
 		nms
 	}
@@ -158,7 +158,7 @@ setMethod("names", signature(x="SpatVector"),
 
 setMethod("names", signature(x="SpatVectorProxy"),
 	function(x) {
-		nms <- x@pnt$v$names
+		nms <- x@cpp$v$names
 		Encoding(nms) <- "UTF-8"
 		nms
 	}
@@ -170,8 +170,8 @@ setMethod("names<-", signature(x="SpatVector"),
 			error("names<-,SpatVector", "incorrect number of names")
 		}
 		value <- enc2utf8(as.character(value))
-		x@pnt <- x@pnt$deepcopy()
-		x@pnt$names <- value
+		x@cpp <- x@cpp$deepcopy()
+		x@cpp$names <- value
 		if (any(names(x) != value)) {
 			warn("names<-", "some names were changed to make them valid and/or unique")
 		}
@@ -182,14 +182,14 @@ setMethod("names<-", signature(x="SpatVector"),
 setMethod("set.names", signature(x="SpatVector"),
 	function(x, value, index=1:ncol(x), validate=FALSE)  {
 		value <- .vector_names_check(x, value, index, validate)
-		x@pnt$names <- value
+		x@cpp$names <- value
 		invisible(TRUE)
 	}
 )
 
 setMethod("varnames", signature(x="SpatRaster"),
 	function(x) {
-		nms <- x@pnt$get_sourcenames()
+		nms <- x@cpp$get_sourcenames()
 		Encoding(nms) <- "UTF-8"
 		nms
 	}
@@ -198,8 +198,8 @@ setMethod("varnames", signature(x="SpatRaster"),
 setMethod("varnames<-", signature(x="SpatRaster"),
 	function(x, value)  {
 		value <- enc2utf8(as.character(value))
-		x@pnt <- x@pnt$deepcopy()
-		if (!x@pnt$set_sourcenames(value)) {
+		x@cpp <- x@cpp$deepcopy()
+		if (!x@cpp$set_sourcenames(value)) {
 			error("varnames<-,SpatRaster", "cannot set these names")
 		}
 		return(x)
@@ -209,7 +209,7 @@ setMethod("varnames<-", signature(x="SpatRaster"),
 
 setMethod("longnames", signature(x="SpatRasterDataset"),
 	function(x) {
-		nms <- x@pnt$long_names
+		nms <- x@cpp$long_names
 		Encoding(nms) <- "UTF-8"
 		nms
 	}
@@ -218,7 +218,7 @@ setMethod("longnames", signature(x="SpatRasterDataset"),
 
 setMethod("longnames", signature(x="SpatRaster"),
 	function(x) {
-		nms <- x@pnt$get_sourcenames_long()
+		nms <- x@cpp$get_sourcenames_long()
 		Encoding(nms) <- "UTF-8"
 		nms
 	}
@@ -226,8 +226,8 @@ setMethod("longnames", signature(x="SpatRaster"),
 
 setMethod("longnames<-", signature(x="SpatRasterDataset"),
 	function(x, value)  {
-		x@pnt <- x@pnt$deepcopy()
-		x@pnt$long_names <- enc2utf8(as.character(value))
+		x@cpp <- x@cpp$deepcopy()
+		x@cpp$long_names <- enc2utf8(as.character(value))
 		return(x)
 	}
 )
@@ -235,9 +235,9 @@ setMethod("longnames<-", signature(x="SpatRasterDataset"),
 
 setMethod("longnames<-", signature(x="SpatRaster"),
 	function(x, value)  {
-		x@pnt <- x@pnt$deepcopy()
+		x@cpp <- x@cpp$deepcopy()
 		value <- enc2utf8(as.character(value))
-		if (!x@pnt$set_sourcenames_long(value)) {
+		if (!x@cpp$set_sourcenames_long(value)) {
 			error("longnames<-,SpatRaster", "cannot set these names")
 		}
 		return(x)
@@ -247,7 +247,7 @@ setMethod("longnames<-", signature(x="SpatRaster"),
 
 setMethod("names", signature(x="SpatVectorCollection"),
 	function(x) {
-		nms <- x@pnt$names
+		nms <- x@cpp$names
 		Encoding(nms) <- "UTF-8"
 		nms
 	}
@@ -256,8 +256,8 @@ setMethod("names", signature(x="SpatVectorCollection"),
 
 setMethod("names<-", signature(x="SpatVectorCollection"),
 	function(x, value) {
-		x@pnt <- x@pnt$deepcopy()
-		x@pnt$setNames(enc2utf8(as.character(value)), FALSE)
+		x@cpp <- x@cpp$deepcopy()
+		x@cpp$setNames(enc2utf8(as.character(value)), FALSE)
 		x
 	}
 )
