@@ -25,7 +25,7 @@
 #endif
 
 
-enum SpatGeomType { points, lines, polygons, unknown, null };
+enum SpatGeomType { points, lines, polygons, null};
 
 
 class SpatHole {
@@ -64,6 +64,7 @@ class SpatPart {
 		bool hasHoles() { return !holes.empty();}
 		unsigned nHoles() { return holes.size();}
 		size_t ncoords();
+		bool is_CCW();
 };
 
 
@@ -75,7 +76,7 @@ class SpatGeom {
 		SpatGeom(SpatPart p, SpatGeomType type);
 		virtual ~SpatGeom(){}
 
-		SpatGeomType gtype = unknown;
+		SpatGeomType gtype = null;
 		std::vector<SpatPart> parts;
 		SpatExtent extent;
 
@@ -215,11 +216,13 @@ class SpatVector {
 		bool read(std::string fname, std::string layer, std::string query, std::vector<double> extent, SpatVector filter, bool as_proxy, std::string what);
 		
 		bool write(std::string filename, std::string lyrname, std::string driver, bool append, bool overwrite, std::vector<std::string>);
+
+		void make_CCW();
 		
 #ifdef useGDAL
 		GDALDataset* write_ogr(std::string filename, std::string lyrname, std::string driver, bool append, bool overwrite, std::vector<std::string> options);
 		GDALDataset* GDAL_ds();
-		bool read_ogr(GDALDataset *poDS, std::string layer, std::string query, std::vector<double> extent, SpatVector filter, bool as_proxy, std::string what);
+		bool read_ogr(GDALDataset *&poDS, std::string layer, std::string query, std::vector<double> extent, SpatVector filter, bool as_proxy, std::string what);
 		SpatVector fromDS(GDALDataset *poDS);
 		bool ogr_geoms(std::vector<OGRGeometryH> &ogrgeoms, std::string &message);		
 		bool delete_layers(std::string filename, std::vector<std::string> layers, bool return_error);		
@@ -386,6 +389,7 @@ class SpatVector {
 		SpatVector densify(double interval, bool adjust, bool ignorelonlat);
 		SpatVector round(int digits);
 		std::vector<unsigned> nullGeoms();
+		std::vector<bool> naGeoms();
 				
 };
 
@@ -396,7 +400,16 @@ class SpatVectorCollection {
 
 	public:
 		virtual ~SpatVectorCollection(){}
+		SpatVectorCollection();
+		SpatVectorCollection(std::string filename, std::string layer, std::string query, std::vector<double> extent, SpatVector filter);
+		
+		
 		SpatVectorCollection deepCopy() { return *this; }
+		bool read(std::string fname, std::string layer, std::string query, std::vector<double> extent, SpatVector filter);
+		
+		bool read_ogr(GDALDataset *&poDS, std::string layer, std::string query, std::vector<double> extent, SpatVector filter);
+
+//		SpatVectorCollection create(std::string filename);
 
 		std::vector<SpatVector> v;
 		std::vector<std::string> names;
